@@ -16,14 +16,14 @@ has label =>
 
 has text_color =>
     ( is      => 'ro',
-      isa     => 'Color',
+      isa     => 'Chart::OFC::Type::Color',
       coerce  => 1,
       default => '#000000',
     );
 
 has text_size =>
     ( is      => 'ro',
-      isa     => 'Size',
+      isa     => 'Chart::OFC::Type::Size',
       default => 20,
     );
 
@@ -90,7 +90,7 @@ This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Dave Rolsky, All Rights Reserved.
+Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
