@@ -12,20 +12,20 @@ extends 'Chart::OFC::Dataset';
 # type in the parent class.
 has 'values' =>
     ( is         => 'ro',
-      isa        => 'NonEmptyArrayRefOfNumsOrUndefs',
+      isa        => 'Chart::OFC::Type::NonEmptyArrayRefOfNumsOrUndefs',
       required   => 1,
       auto_deref => 1,
     );
 
 has width =>
     ( is      => 'ro',
-      isa     => 'PosInt',
+      isa     => 'Chart::OFC::Type::PosInt',
       default => 2,
     );
 
 has color =>
     ( is      => 'ro',
-      isa     => 'Color',
+      isa     => 'Chart::OFC::Type::Color',
       coerce  => 1,
       default => '#000000',
     );
@@ -38,7 +38,7 @@ has label =>
 
 has text_size =>
     ( is      => 'ro',
-      isa     => 'Size',
+      isa     => 'Chart::OFC::Type::Size',
       default => 10,
     );
 
@@ -47,26 +47,7 @@ sub type
     return 'line';
 }
 
-sub _ofc_data_lines
-{
-    my $self  = shift;
-    my $count = shift;
-
-    my $name = $self->type();
-    $name .= q{_} . $count
-        if $count && $count > 1;
-
-    my $val_name = 'values';
-    $val_name .= q{_} . $count
-        if $count && $count > 1;
-
-    return
-        ( $self->_data_line( $name, $self->_line_parameters() ),
-          $self->_data_line( $val_name, $self->values() ),
-        );
-}
-
-sub _line_parameters
+sub _parameters_for_type
 {
     my $self = shift;
 
@@ -116,6 +97,10 @@ class's attributes as well as its own.
 For this class, the values array may contain some undefined
 values. These are simply skipped in the resulting chart.
 
+=head2 links
+
+Just as with values, this may contain some undefined values.
+
 =head2 width
 
 The width of the line in pixels.
@@ -147,7 +132,7 @@ This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Dave Rolsky, All Rights Reserved.
+Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
