@@ -16,7 +16,7 @@ has solid_dots =>
 
 has dot_size =>
     ( is      => 'ro',
-      isa     => 'PosInt',
+      isa     => 'Chart::OFC::Type::PosInt',
       default => 5,
     );
 
@@ -27,7 +27,7 @@ sub type
     return $self->solid_dots() ? 'line_dot' : 'line_hollow';
 }
 
-sub _line_parameters
+sub _parameters_for_type
 {
     my $self = shift;
 
@@ -92,7 +92,7 @@ This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Dave Rolsky, All Rights Reserved.
+Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
