@@ -35,7 +35,7 @@ has large_tick_size =>
 
 has label_steps =>
     ( is       => 'ro',
-      isa      => 'PosInt',
+      isa      => 'Chart::OFC::Type::PosInt',
       required => 1,
     );
 
@@ -136,7 +136,7 @@ This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Dave Rolsky, All Rights Reserved.
+Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
